@@ -4,8 +4,6 @@ Groups
 """
 from __future__ import with_statement
 
-from pipes import quote
-
 from fabric.api import hide, run, settings
 
 from fabtools.utils import run_as_root
@@ -34,7 +32,7 @@ def create(name, gid=None):
 
     args = []
     if gid:
-        args.append('-g %s' % quote(gid))
+        args.append('-g %s' % gid)
     args.append(name)
     args = ' '.join(args)
     run_as_root('groupadd %s' % args)
